/**
 * The Sencha Grid store filter properties.
 */
export interface FilterProps {
    /**
     * Define if the filter is active.
     */
    active?: boolean;
    /**
     * A custom filter function which is passed each item.
     */
    filterFn?(value: any): boolean;
    /**
     * The operator to use to compare the `property` to this Filter's `value`.
     *
     * The in and notin operator expects this filter's data model value to be an array and matches values that are present in that array.
     * The like operator matches values that contain this filter's data model value as a substring.
     * The /= operator uses the data model value as the source for a RegExp and tests whether the candidate value matches the regular expression.
     */
    operator?: "<" | "<=" | "=" | ">=" | ">" | "!=" | "in" | "notin" | "like" | "/=";
    /**
     * The property to filter on. Required unless a filterFn is passed.
     */
    property: string;
    /**
     *
     */
    value: string | RegExp;
}
export default FilterProps;
