/**
 * Event listener class
 */
var EventListeners = /** @class */ (function () {
    function EventListeners(props) {
        this.gridProps = props;
    }
    EventListeners.prototype.selectionChange = function (grid, records, selected) {
        var onSelect = this.gridProps.onSelect;
        var onSelectParam;
        if (grid.config.selectable.cells) {
            // convert cell selection array to an object
            var cellSelection = {
                firstColumnIndex: records[0][0],
                firstRowIndex: records[0][1],
                lastColumnIndex: records[1][0],
                lastRowIndex: records[1][1],
            };
            onSelectParam = {
                records: cellSelection,
                selected: selected,
            };
        }
        else {
            var selectedIndex = grid.getStore().indexOf(records[0]);
            onSelectParam = {
                records: records.map(function (record) { return record.data; }),
                selected: selected,
                selectedIndex: selectedIndex,
            };
        }
        onSelect && onSelect(onSelectParam);
    };
    EventListeners.prototype.columnhide = function (grid, column) {
        var onColumnHide = this.gridProps.onColumnHide;
        if (onColumnHide) {
            var columnHideParams = {
                column: column,
                fieldName: column.getField(),
                title: column.getText(),
            };
            onColumnHide(columnHideParams);
        }
    };
    EventListeners.prototype.beforecomplete = function (editor, value, oldValue, location) {
        var onBeforeComplete = this.gridProps.onBeforeComplete;
        if (onBeforeComplete) {
            var onBeforeCompleteParam = void 0;
            onBeforeCompleteParam = {
                value: value,
                oldValue: oldValue,
                columnIndex: location.columnIndex,
                recordIndex: location.recordIndex,
            };
            onBeforeComplete(onBeforeCompleteParam);
        }
    };
    EventListeners.prototype.beforegroupcollapse = function (value, group) {
        var onBeforeGroupCollapse = this.gridProps.onBeforeGroupCollapse;
        if (onBeforeGroupCollapse) {
            var onBeforeGroupCollapseParam = void 0;
            var groupedData = [];
            for (var i = 0; i < group.data.items.length; i++) {
                groupedData.push(group.data.items[i].data);
            }
            onBeforeGroupCollapseParam = {
                collapsedGroupData: groupedData,
                collapsedBeginIndex: group.beginIndex,
                collapsedEndIndex: group.endIndex,
                collapsed: group.collapsed,
            };
            onBeforeGroupCollapse(onBeforeGroupCollapseParam);
        }
    };
    EventListeners.prototype.beforegroupexpand = function (value, group) {
        var onBeforeGroupExpand = this.gridProps.onBeforeGroupExpand;
        if (onBeforeGroupExpand) {
            var onBeforeGroupExpandParam = void 0;
            var groupedData = [];
            for (var i = 0; i < group.data.items.length; i++) {
                groupedData.push(group.data.items[i].data);
            }
            onBeforeGroupExpandParam = {
                expandGroupData: groupedData,
                expandBeginIndex: group.beginIndex,
                expandEndIndex: group.endIndex,
                collapsed: group.collapsed,
            };
            onBeforeGroupExpand(onBeforeGroupExpandParam);
        }
    };
    EventListeners.prototype.cellselection = function (grid, selection) {
        var onCellSelection = this.gridProps.onCellSelection;
        if (onCellSelection) {
            var onCellSelectionParam = void 0;
            onCellSelectionParam = {
                columnIndex: selection[0][0],
                rowIndex: selection[0][1],
            };
            onCellSelection(onCellSelectionParam);
        }
    };
    EventListeners.prototype.beforeEdit = function (grid, location, eOpts) {
        var onBeforeEdit = this.gridProps.onBeforeEdit;
        if (onBeforeEdit) {
            var onBeforeEditParam = {
                columnIndex: location.columnIndex,
                recordIndex: location.recordIndex,
            };
            return onBeforeEdit(onBeforeEditParam);
        }
    };
    EventListeners.prototype.columnmove = function (grid, column, fromIndex, toIndex, acceptEvent) {
        if (typeof acceptEvent !== "boolean" && acceptEvent) {
            return;
        }
        var onColumnMove = this.gridProps.onColumnMove;
        if (onColumnMove) {
            var onColumnMoveParams = {
                column: column,
                fromIndex: fromIndex,
                toIndex: toIndex,
            };
            console.log("Event Fired Once");
            onColumnMove(onColumnMoveParams);
        }
    };
    EventListeners.prototype.columnadd = function (grid, column, index) {
        var onColumnAdd = this.gridProps.onColumnAdd;
        if (onColumnAdd) {
            var columnAddData = {
                column: column,
                index: index,
            };
            onColumnAdd(columnAddData);
        }
    };
    EventListeners.prototype.columnresize = function (grid, column) {
        var onColumnResize = this.gridProps.onColumnResize;
        if (onColumnResize) {
            var onColumnResizeParams = {
                fieldName: column.getField(),
                width: column.getWidth(),
                title: column.getText(),
            };
            onColumnResize(onColumnResizeParams);
        }
    };
    EventListeners.prototype.deselect = function (grid, record) {
        var _a;
        var onDeSelect = this.gridProps.onDeSelect;
        if (onDeSelect) {
            var deselectParams = {
                record: (_a = record[0]) === null || _a === void 0 ? void 0 : _a.getData(),
            };
            onDeSelect(deselectParams);
        }
    };
    EventListeners.prototype.beforestartedit = function (editor, boundEl, value, location) {
        var onBeforeStartEdit = this.gridProps.onBeforeStartEdit;
        if (onBeforeStartEdit) {
            var beforestarteditParams = {
                value: value,
                boundEl: boundEl.dom,
                rowIndex: location.recordIndex,
                columnIndex: location.columnIndex,
            };
            onBeforeStartEdit(beforestarteditParams);
        }
    };
    EventListeners.prototype.columnsort = function (grid, column, direction) {
        var onColumnSort = this.gridProps.onColumnSort;
        if (onColumnSort) {
            var onColumnsortParams = {
                direction: direction,
                fieldName: column.getField(),
                columnIndex: grid.getColumns().indexOf(column),
            };
            onColumnSort(onColumnsortParams);
        }
    };
    EventListeners.prototype.startedit = function (editor, boundEl, value, location) {
        var onStartEdit = this.gridProps.onStartEdit;
        if (onStartEdit) {
            var onStarteditParams = {
                value: value,
                boundEl: boundEl.dom,
                rowIndex: location.recordIndex,
                columnIndex: location.columnIndex,
            };
            onStartEdit(onStarteditParams);
        }
    };
    EventListeners.prototype.updatedata = function (sender, newData) {
        var onUpdateData = this.gridProps.onUpdateData;
        if (onUpdateData) {
            var onUpdatedataParams = {
                data: newData,
            };
            onUpdateData(onUpdatedataParams);
        }
    };
    EventListeners.prototype.complete = function (editor, value, oldValue) {
        var onComplete = this.gridProps.onComplete;
        if (onComplete) {
            var onCompleteEditParam = void 0;
            onCompleteEditParam = {
                value: value,
                oldValue: oldValue,
            };
            onComplete(onCompleteEditParam);
        }
    };
    EventListeners.prototype.columnselection = function (grid, selection) {
        var onColumnSelection = this.gridProps.onColumnSelection;
        if (onColumnSelection) {
            selection = selection.map(function (column) { return ({
                fieldName: column.getField(),
                columnIndex: grid.getColumns().indexOf(column),
            }); });
            for (var i = 0; i < selection.length; i++) {
                var onColumnselectionParams = {
                    fieldName: selection[i].fieldName,
                    columnIndex: selection[i].columnIndex,
                };
                onColumnSelection(onColumnselectionParams);
            }
        }
    };
    EventListeners.prototype.focus = function (grid, event) {
        var onGridFocus = this.gridProps.onGridFocus;
        if (onGridFocus) {
            onGridFocus();
        }
    };
    EventListeners.prototype.blur = function (grid, event) {
        var onGridBlur = this.gridProps.onGridBlur;
        if (onGridBlur) {
            onGridBlur();
        }
    };
    EventListeners.prototype.columnmenucreated = function (grid, column, menu) {
        var onColumnMenuCreated = this.gridProps.onColumnMenuCreated;
        menu.items.items = menu.items.items.map(function (item) {
            return item;
        });
        if (onColumnMenuCreated) {
            var onColumnmenucreatedParams = void 0;
            onColumnmenucreatedParams = {
                menuItems: menu.items.items,
                fieldName: column.getField(),
                columnIndex: grid.getColumns().indexOf(column),
                menuDomElement: menu.el.dom,
            };
            onColumnMenuCreated(onColumnmenucreatedParams);
        }
    };
    EventListeners.prototype.edit = function (grid, location) {
        var onEdit = this.gridProps.onEdit;
        if (onEdit) {
            var data = {
                columnIndex: location.columnIndex,
                rowIndex: location.recordIndex,
                rowData: location.record.data,
            };
            onEdit(data);
        }
    };
    EventListeners.prototype.canceledit = function (grid, value, startValue) {
        var onCancelEdit = this.gridProps.onCancelEdit;
        if (onCancelEdit) {
            var data = {
                rowIndex: value.recordIndex,
            };
            onCancelEdit(data);
        }
    };
    EventListeners.prototype.validateedit = function (sender, location) {
        var onValidateEdit = this.gridProps.onValidateEdit;
        var editConfirmation;
        if (onValidateEdit) {
            var data = {
                data: sender.record.data,
            };
            editConfirmation = onValidateEdit(data);
        }
        return editConfirmation;
    };
    EventListeners.prototype.painted = function (sender, element) {
        var onPainted = this.gridProps.onPainted;
        if (onPainted) {
            var data = {
                domEl: element.dom,
            };
            onPainted(data);
        }
    };
    EventListeners.prototype.initialize = function (sender) {
        var onInitialize = this.gridProps.onInitialize;
        if (onInitialize) {
            onInitialize();
        }
    };
    EventListeners.prototype.childdoubletap = function (grid, location) {
        var onChildDoubleTap = this.gridProps.onChildDoubleTap;
        if (onChildDoubleTap) {
            var params = {
                selectedIndex: location.recordIndex,
                record: location.record,
            };
            onChildDoubleTap(params);
        }
    };
    EventListeners.prototype.childsingletap = function (grid, location) {
        var onRowClick = this.gridProps.onRowClick;
        if (onRowClick) {
            var params = {
                selectedIndex: location.recordIndex,
                record: location.record,
            };
            onRowClick(params);
        }
    };
    EventListeners.prototype.columnshow = function (grid, column) {
        var onColumnShow = this.gridProps.onColumnShow;
        if (onColumnShow) {
            var params = {
                column: column,
            };
            onColumnShow(params);
        }
    };
    return EventListeners;
}());
export { EventListeners };
export default EventListeners;
